#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
SAT plugin for managing xep-0045
Copyright (C) 2009, 2010  Jérôme Poisson (goffi@goffi.org)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from logging import debug, info, warning, error
from twisted.words.xish import domish
from twisted.internet import protocol, defer, threads, reactor
from twisted.words.protocols.jabber import client, jid, xmlstream
from twisted.words.protocols.jabber import error as jab_error
from twisted.words.protocols.jabber.xmlstream import IQ
from twisted.web.client import getPage
import os.path
import pdb
import random

from zope.interface import implements

from wokkel import disco, iwokkel, data_form
from tools.xml_tools import dataForm2xml
import urllib

from BeautifulSoup import BeautifulSoup



PLUGIN_INFO = {
"name": "CouchSurfing plugin",
"import_name": "CS",
"type": "Misc",
"protocols": [],
"dependencies": [],
"main": "CS_Plugin",
"handler": "no",
"description": _(u"""This plugin allow to manage your CouchSurfing account throught your SàT frontend""")
}

AGENT = 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.3) Gecko/20100423 Ubuntu/10.04 (lucid) Firefox/3.6.3'

class CS_Plugin():

    params = """
    <params>
    <individual>
    <category name="CouchSurfing">
        <param name="Login" type="string" />
        <param name="Password" type="password" />
    </category>
    </individual>
    </params>
    """

    def __init__(self, host):
        info(_("Plugin CS initialization"))
        self.host = host
        #parameters
        host.memory.importParams(CS_Plugin.params)
        #menu
        host.importMenu(_("Plugin"), "CouchSurfing", self.menuSelected, help_string = _("Launch CoushSurfing mangement interface"))
        self.data={} #TODO: delete cookies/data after a while

    def erroCB(self, e, id):
        """Called when something is going wrong when contacting CS website"""
        message_data={"reason": "connection error", "message":_(u"Impossible to contact CS website, please check your login/password, connection or try again later")}
        self.host.bridge.actionResult("ERROR", id, message_data)


    def menuSelected(self, id, profile):
        """Called when the couchsurfing menu item is selected"""
        login = self.host.memory.getParamA("Login", "CouchSurfing", profile_key=profile)
        password = self.host.memory.getParamA("Password", "CouchSurfing", profile_key=profile)
        if not login or not password:
            message_data={"reason": "uncomplete", "message":_(u"You have to fill your CouchSurfing login & password in parameters before using this interface")}
            self.host.bridge.actionResult("ERROR", id, message_data)
            return

        post_data = urllib.urlencode({'auth_login[un]':login,'auth_login[pw]':password,'auth_login[action]':'Login...'}) 
        
        self.data[profile] = {'cookies':{}}

        def connectionCB(html):
            print 'Response received'
            soup = self.data[profile]['soup'] = BeautifulSoup(html)
            user_nick = soup.find('a','item_link',href='/home.html').contents[0]
            user_name = soup.html.head.title.string.split(' - ')[1]
            unread_messages = int(soup.find('div','item_bubble').a.string)
            form_xml = """
            <form>
                <elem type='text' value='Welcome %(name)s, you have %(nb_message)i unread messages'/>
            </form>
            """ % {'name':user_name, 'nb_message':unread_messages}
            self.host.bridge.actionResult("FORM", id, {"type":"window", "xml":form_xml})



            #d = getPage('http://www.couchsurfing.org/messages.html?message_status=inbox', agent=AGENT, cookies=self.session_cookies[profile])
       
        #tmp
        f = open('/home/goffi/tmp/CS_principale.html','r')
        html = f.read()
        connectionCB(html)

        """d = getPage('http://www.couchsurfing.org/login.html', method='POST', postdata=post_data, headers={'Content-Type':'application/x-www-form-urlencoded'} , agent=AGENT, cookies=self.data[profile]['cookies'])
        d.addCallback(connectionCB)
        d.addErrback(self.erroCB, id)"""


        #self.host.bridge.actionResult("SUPPRESS", id, {})



